@@ -24,9 +24,6 @@
 
 #include "graveman.h"
 
-static gchar *_precdirectory = NULL;  /* dernier emplacement utilis dans une boite
-                                         dialogue gtk_file_chooser */
-
 /* affichage boite de dialogue au sujet de ... */
 void on_about (GtkMenuItem *Amenuitem, gpointer Adata)
 {
@@ -63,23 +60,44 @@ void _add_a_piste(gchar *Anom, GtkListStore *Aliststore, GHashTable *Ahash)
   GtkTreeIter Liter;
   gchar *LTitle = NULL, *LAlbum = NULL, *LArtist = NULL;
   guint32 Llennbr = 0;
-  gchar *Lnameutf8 = NULL, *Llengthutf8 = NULL;
+  gchar *Lfullnameutf8 = NULL, *Lnameutf8 = NULL, *Llengthutf8 = NULL;
   gchar *Lname;
+  gboolean Lstatus = FALSE;
 
   /* on reconnai le type fichier grace a son extension */
 
 #ifdef ENABLE_MP3
   if (sc_str_has_casesuffix(Anom, MP3)) {
-    getMp3Info(Anom, &LTitle, &LAlbum, &LArtist, &Llennbr, NULL);
+    Lstatus = getMp3Info(Anom, &LTitle, &LAlbum, &LArtist, &Llennbr, NULL);
   } else
 #endif    
 #ifdef ENABLE_OGG
   if (sc_str_has_casesuffix(Anom, OGG)) {
-    getOggInfo(Anom, &LTitle, &LAlbum, &LArtist, &Llennbr, NULL);
+    Lstatus = getOggInfo(Anom, &LTitle, &LAlbum, &LArtist, &Llennbr, NULL);
   } else
 #endif
   if (sc_str_has_casesuffix(Anom, WAV)) {
-    getWavInfo(Anom, &Llennbr, NULL);
+    Lstatus = getWavInfo(Anom, &Llennbr, NULL);
+  }
+
+  if (Lstatus == FALSE) {
+    /* erreur format inconnue ou incorecte */
+    gchar *Ltmp;
+    GtkWidget *Lerrdiag;
+    
+    Lnameutf8 = _UTF8(Anom);
+    Ltmp = g_strdup_printf(_("Cannot add track '%s', this is an unknown or invalid audio file."),
+        Lnameutf8);
+    g_free(Lnameutf8);
+
+    Lerrdiag = gtk_message_dialog_new(NULL,
+                        GTK_DIALOG_MODAL, GTK_MESSAGE_WARNING, GTK_BUTTONS_CANCEL, Ltmp);
+    gtk_dialog_run(GTK_DIALOG(Lerrdiag));
+    gtk_widget_destroy(Lerrdiag);
+
+    g_free(Ltmp);
+
+    return;
   }
 
   if ((!LTitle && !LAlbum && !LArtist) ||
@@ -94,11 +112,11 @@ void _add_a_piste(gchar *Anom, GtkListStore *Aliststore, GHashTable *Ahash)
   *(Laudiolen)=*(Laudiolen) + Llennbr;
   gtk_list_store_append(Aliststore, &Liter);
   Llengthutf8 = format_length(Llennbr);
+  Lfullnameutf8 = _UTF8(Anom);
+
   gtk_list_store_set(Aliststore, &Liter, 0, TYPE_MP3, 1, GAudioIcone, 2, Lnameutf8, 3,
-                      Llengthutf8, 4, Anom, 5, Llennbr, -1);
-  g_free(Llengthutf8);
-  g_free(Lnameutf8);
-  g_free(Lname);
+                      Llengthutf8, 4, Lfullnameutf8, 5, Anom, 6, Llennbr, -1);
+  g_free(Lfullnameutf8); g_free(Llengthutf8); g_free(Lnameutf8); g_free(Lname);
 
   g_free(LArtist);
   g_free(LAlbum); g_free(LTitle);
@@ -114,7 +132,7 @@ void _add_a_file(gchar *Anom, GtkTreeStore *ATreeStore, GtkTreeIter *Aparent, GH
   DIR *Ldir;
   struct dirent *Lcurfic;
   gchar *Lfullname;
-/*  gchar *Lonlynameutf8, *Lnomutf8, */
+  gchar *Lonlynameutf8, *Lnomutf8;
   gchar *Lformatsizeutf8;
 
   if ((LOnlyName=strrchr(Anom, '/'))) {
@@ -134,11 +152,11 @@ void _add_a_file(gchar *Anom, GtkTreeStore *ATreeStore, GtkTreeIter *Aparent, GH
     /* si c'est un repertoire alors on lis tout son contenu et on ajoute
      * les fichiers qu'il contient */
 
-/*    Lonlynameutf8 = _UTF8(LOnlyName);
-    Lnomutf8 = _UTF8(Anom);*/
-    gtk_tree_store_set(ATreeStore, &Liter, 0, TYPE_DIR, 1, GDirIcone, 2, LOnlyName, 3, "", 4, Anom, 5, 0, -1);
-/*    g_free(Lnomutf8);
-    g_free(Lonlynameutf8);*/
+    Lonlynameutf8 = _UTF8(LOnlyName);
+    Lnomutf8 = _UTF8(Anom);
+    gtk_tree_store_set(ATreeStore, &Liter, 0, TYPE_DIR, 1, GDirIcone, 2, Lonlynameutf8, 3, "", 4, Lnomutf8, 5, LOnlyName, 6, 0, -1);
+    g_free(Lnomutf8);
+    g_free(Lonlynameutf8);
 
     Ldir = opendir(Anom);
     if (!Ldir) {
@@ -156,14 +174,14 @@ void _add_a_file(gchar *Anom, GtkTreeStore *ATreeStore, GtkTreeIter *Aparent, GH
     closedir(Ldir);
     
   } else {
-/*    Lonlynameutf8 = _UTF8(LOnlyName);
-    Lnomutf8 = _UTF8(Anom);*/
+    Lonlynameutf8 = _UTF8(LOnlyName);
+    Lnomutf8 = _UTF8(Anom);
     Lformatsizeutf8 = format_size(Lfi.st_size);
-    gtk_tree_store_set(ATreeStore, &Liter, 0, TYPE_FILE, 1, GFileIcone, 2, LOnlyName,
-                                           3, Lformatsizeutf8, 4, Anom, 5, Lfi.st_size, -1);
+    gtk_tree_store_set(ATreeStore, &Liter, 0, TYPE_FILE, 1, GFileIcone, 2, Lonlynameutf8,
+                                           3, Lformatsizeutf8, 4, Lnomutf8, 5, Anom, 6, Lfi.st_size, -1);
     g_free(Lformatsizeutf8);
-/*    g_free(Lnomutf8);
-    g_free(Lonlynameutf8);*/
+    g_free(Lnomutf8);
+    g_free(Lonlynameutf8);
 
     *(Ldatasize)=*(Ldatasize) + Lfi.st_size;
   }
@@ -447,10 +465,9 @@ void gtk_audio_addtrack(GtkWidget *Abtn, gpointer Adata)
   GtkWidget *Lpistesel = create_addpisteselection(NULL);
   GSList *Lfiles, *Lcur;
 
-  if (_precdirectory) gtk_file_chooser_set_current_folder_uri(GTK_FILE_CHOOSER(Lpistesel), _precdirectory);
+  use_last_dir(GTK_FILE_CHOOSER(Lpistesel));
   if (gtk_dialog_run(GTK_DIALOG(Lpistesel))==GTK_RESPONSE_ACCEPT) {
-    if (_precdirectory) g_free(_precdirectory);
-    _precdirectory = gtk_file_chooser_get_current_folder_uri(GTK_FILE_CHOOSER(Lpistesel));
+    save_last_dir(GTK_FILE_CHOOSER(Lpistesel));
 
     Lfiles = gtk_file_chooser_get_filenames(GTK_FILE_CHOOSER(Lpistesel));
 
@@ -497,10 +514,9 @@ void gtk_data_adddirectory(GtkWidget *btn, gpointer Adata)
     gtk_tree_path_free(Lpath);
   }
 
-  if (_precdirectory) gtk_file_chooser_set_current_folder_uri(GTK_FILE_CHOOSER(Lfilesel), _precdirectory);
+  use_last_dir(GTK_FILE_CHOOSER(Lfilesel));
   if (gtk_dialog_run(GTK_DIALOG(Lfilesel))==GTK_RESPONSE_ACCEPT) {
-    if (_precdirectory) g_free(_precdirectory);
-    _precdirectory = gtk_file_chooser_get_current_folder_uri(GTK_FILE_CHOOSER(Lfilesel));
+    save_last_dir(GTK_FILE_CHOOSER(Lfilesel));
 
     Lfiles = gtk_file_chooser_get_filenames(GTK_FILE_CHOOSER(Lfilesel));
 	
@@ -552,10 +568,9 @@ void gtk_data_addfile(GtkWidget *btn, gpointer Adata)
     gtk_tree_path_free(Lpath);
   }
 
-  if (_precdirectory) gtk_file_chooser_set_current_folder_uri(GTK_FILE_CHOOSER(Lfilesel), _precdirectory);
+  use_last_dir(GTK_FILE_CHOOSER(Lfilesel));
   if (gtk_dialog_run(GTK_DIALOG(Lfilesel))==GTK_RESPONSE_ACCEPT) {
-    if (_precdirectory) g_free(_precdirectory);
-    _precdirectory = gtk_file_chooser_get_current_folder_uri(GTK_FILE_CHOOSER(Lfilesel));
+    save_last_dir(GTK_FILE_CHOOSER(Lfilesel));
 
     Lfiles = gtk_file_chooser_get_filenames(GTK_FILE_CHOOSER(Lfilesel));
 	
@@ -722,7 +737,7 @@ _DEB("=>%s\n", Lname);
     Ldialogtype = GTK_FILE_CHOOSER_ACTION_SELECT_FOLDER;
   }
   Lfilesel = create_fileselection1(NULL, Ldialogtype);
-  if (_precdirectory) gtk_file_chooser_set_current_folder_uri(GTK_FILE_CHOOSER(Lfilesel), _precdirectory);
+  use_last_dir(GTK_FILE_CHOOSER(Lfilesel));
   resp=gtk_dialog_run(GTK_DIALOG(Lfilesel));
   gtk_widget_hide (Lfilesel);
   while (gtk_events_pending())
@@ -731,8 +746,7 @@ _DEB("=>%s\n", Lname);
   if (resp == GTK_RESPONSE_ACCEPT) {
     gchar *Lfilenamebrut = gtk_file_chooser_get_filename(GTK_FILE_CHOOSER ( Lfilesel));
     gchar *Lfilename = _UTF8(Lfilenamebrut);
-    if (_precdirectory) g_free(_precdirectory);
-    _precdirectory = gtk_file_chooser_get_current_folder_uri(GTK_FILE_CHOOSER(Lfilesel));
+    save_last_dir(GTK_FILE_CHOOSER(Lfilesel));
     gtk_entry_set_text(GTK_ENTRY(Ltextdest), Lfilename);
     g_free(Lfilename);
     g_free(Lfilenamebrut);
